#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client-tls
version:              0.3.6.4
visibility:           public
id:                   http-client-tls-0.3.6.4-Dj2m0zumhuN7HSttI52C5a
key:                  http-client-tls-0.3.6.4-Dj2m0zumhuN7HSttI52C5a
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:
    http-client backend using the connection package and tls library

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.

category:             Network
abi:                  c604d99ae3c288d8dd267ad76d87fbc0
exposed:              True
exposed-modules:      Network.HTTP.Client.TLS
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-client-tls-0.3.6.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-client-tls-0.3.6.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-client-tls-0.3.6.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.6.6/http-client-tls-0.3.6.4
hs-libraries:         HShttp-client-tls-0.3.6.4-Dj2m0zumhuN7HSttI52C5a
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-A8CTHJLbf7AArK6CnJHSQw containers-0.6.7
    crypton-1.0.5-ISaCEA7WOGuAiZSS5ibrwY
    crypton-connection-0.4.5-28PDMzn4kwWIyavOflPWl4
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG exceptions-0.10.7
    http-client-0.7.19-JFk9tUfcyF3FnWNRzLmEjW
    http-types-0.12.4-FjxwRmZWhoR3wzry1r4T66
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-9nB9sbnLDjyBVIWLW7TDGb
    network-uri-2.6.4.2-2pvBC2E3r3ZG7itzgqfKfv text-2.0.2
    tls-2.0.6-KODXqScNPtDErnnkyIokYw transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock

haddock-html:         /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

